@@ -452,6 +452,36 @@ class CmeClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePlatforms(self, request):
+        """<li>支持获取所创建的所有平台列表信息；</li>
+        <li>支持获取指定的平台列表信息。</li>
+
+
+        :param request: Request instance for DescribePlatforms.
+        :type request: :class:`tencentcloud.cme.v20191029.models.DescribePlatformsRequest`
+        :rtype: :class:`tencentcloud.cme.v20191029.models.DescribePlatformsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePlatforms", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePlatformsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeProjects(self, request):
         """支持根据多种条件过滤出项目列表。
 
@@ -623,7 +653,7 @@ class CmeClient(AbstractClient):
 
 
     def DescribeTeams(self, request):
-        """获取指定团队的信息。
+        """获取指定团队的信息，拉取团队信息列表。
 
         :param request: Request instance for DescribeTeams.
         :type request: :class:`tencentcloud.cme.v20191029.models.DescribeTeamsRequest`
@@ -819,7 +849,7 @@ class CmeClient(AbstractClient):
 
 
     def ImportMaterial(self, request):
-        """将云点播媒资文件导入到云剪素材库。
+        """将云点播媒资文件导入到云剪媒体资源库。
 
         :param request: Request instance for ImportMaterial.
         :type request: :class:`tencentcloud.cme.v20191029.models.ImportMaterialRequest`
@@ -847,7 +877,7 @@ class CmeClient(AbstractClient):
 
 
     def ImportMediaToProject(self, request):
-        """将云点播中的媒资添加到素材库中，供后续视频编辑使用。
+        """将云点播中的媒资或者用户自有媒资文件添加到媒体库中，供后续视频编辑使用。
 
         :param request: Request instance for ImportMediaToProject.
         :type request: :class:`tencentcloud.cme.v20191029.models.ImportMediaToProjectRequest`
