@@ -55,7 +55,7 @@ class MonitorClient(AbstractClient):
 
 
     def CreateAlarmNotice(self, request):
-        """云监控告警创建告警通知模板
+        """创建通知模板
 
         :param request: Request instance for CreateAlarmNotice.
         :type request: :class:`tencentcloud.monitor.v20180724.models.CreateAlarmNoticeRequest`
@@ -339,7 +339,7 @@ class MonitorClient(AbstractClient):
 
 
     def DescribeAlarmHistories(self, request):
-        """告警历史列表
+        """查询告警历史
 
         :param request: Request instance for DescribeAlarmHistories.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeAlarmHistoriesRequest`
@@ -395,7 +395,7 @@ class MonitorClient(AbstractClient):
 
 
     def DescribeAlarmNotice(self, request):
-        """云监控告警获取告警通知模板详情
+        """查询单个通知模板的详情
 
         :param request: Request instance for DescribeAlarmNotice.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeAlarmNoticeRequest`
@@ -451,7 +451,7 @@ class MonitorClient(AbstractClient):
 
 
     def DescribeAlarmNotices(self, request):
-        """云监控告警查询告警通知模板列表
+        """查询通知模板列表
 
         :param request: Request instance for DescribeAlarmNotices.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeAlarmNoticesRequest`
@@ -479,7 +479,7 @@ class MonitorClient(AbstractClient):
 
 
     def DescribeAlarmPolicies(self, request):
-        """告警策略列表
+        """查询告警策略列表
 
         :param request: Request instance for DescribeAlarmPolicies.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeAlarmPoliciesRequest`
@@ -507,7 +507,7 @@ class MonitorClient(AbstractClient):
 
 
     def DescribeAlarmPolicy(self, request):
-        """告警策略详情
+        """获取单个告警策略详情
 
         :param request: Request instance for DescribeAlarmPolicy.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeAlarmPolicyRequest`
@@ -535,7 +535,7 @@ class MonitorClient(AbstractClient):
 
 
     def DescribeAllNamespaces(self, request):
-        """拉取所有名字空间
+        """查询所有名字空间
 
         :param request: Request instance for DescribeAllNamespaces.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeAllNamespacesRequest`
@@ -844,6 +844,34 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeStatisticData(self, request):
+        """根据维度条件查询监控数据
+
+        :param request: Request instance for DescribeStatisticData.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeStatisticDataRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.DescribeStatisticDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeStatisticData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeStatisticDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetMonitorData(self, request):
         """获取云产品的监控数据。传入产品的命名空间、对象维度描述和监控指标即可获得相应的监控数据。
         接口调用频率限制为：20次/秒，1200次/分钟。单请求最多可支持批量拉取10个实例的监控数据，单请求的数据点数限制为1440个。
@@ -987,7 +1015,7 @@ class MonitorClient(AbstractClient):
 
 
     def ModifyAlarmPolicyStatus(self, request):
-        """修改告警策略的启停状态
+        """启停告警策略
 
         :param request: Request instance for ModifyAlarmPolicyStatus.
         :type request: :class:`tencentcloud.monitor.v20180724.models.ModifyAlarmPolicyStatusRequest`
