@@ -85,7 +85,7 @@ class OcrClient(AbstractClient):
 
 
     def BankCardOCR(self, request):
-        """本接口支持对中国大陆主流银行卡的卡号、银行信息、有效期等关键字段的检测与识别。
+        """本接口支持对中国大陆主流银行卡正反面关键字段的检测与识别，包括卡号、卡类型、卡名字、银行信息、有效期。支持竖排异形卡识别、多角度旋转图片识别。支持对复印件、翻拍件、边框遮挡的银行卡进行告警，可应用于各种银行卡信息有效性校验场景，如金融行业身份认证、第三方支付绑卡等场景。
 
         :param request: Request instance for BankCardOCR.
         :type request: :class:`tencentcloud.ocr.v20181119.models.BankCardOCRRequest`
@@ -255,7 +255,7 @@ class OcrClient(AbstractClient):
     def DriverLicenseOCR(self, request):
         """本接口支持驾驶证主页和副页所有字段的自动定位与识别，重点字段的识别准确度达到99%以上。
 
-        驾驶证主页：包括证号、姓名、性别、国籍、住址、出生日期、初次领证日期、准驾车型、有效期限。
+        驾驶证主页：包括证号、姓名、性别、国籍、住址、出生日期、初次领证日期、准驾车型、有效期限、发证单位
 
         驾驶证副页：包括证号、姓名、档案编号、记录。
 
