@@ -23,6 +23,7 @@ from tencentcloud.tcr.v20190924 import models
 class TcrClient(AbstractClient):
     _apiVersion = '2019-09-24'
     _endpoint = 'tcr.tencentcloudapi.com'
+    _service = 'tcr'
 
 
     def BatchDeleteImagePersonal(self, request):
@@ -1033,6 +1034,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeInternalEndpoints(self, request):
+        """查询实例内网访问VPC链接
+
+        :param request: Request instance for DescribeInternalEndpoints.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.DescribeInternalEndpointsRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.DescribeInternalEndpointsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInternalEndpoints", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInternalEndpointsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeNamespacePersonal(self, request):
         """查询个人版命名空间信息
 
@@ -1397,6 +1426,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ManageInternalEndpoint(self, request):
+        """管理实例内网访问VPC链接
+
+        :param request: Request instance for ManageInternalEndpoint.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.ManageInternalEndpointRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.ManageInternalEndpointResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ManageInternalEndpoint", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ManageInternalEndpointResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyApplicationTriggerPersonal(self, request):
         """用于修改应用更新触发器
 
@@ -1621,6 +1678,34 @@ class TcrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RenewInstance(self, request):
+        """预付费实例续费，同时支持按量计费转包年包月
+
+        :param request: Request instance for RenewInstance.
+        :type request: :class:`tencentcloud.tcr.v20190924.models.RenewInstanceRequest`
+        :rtype: :class:`tencentcloud.tcr.v20190924.models.RenewInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RenewInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RenewInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ValidateNamespaceExistPersonal(self, request):
         """查询个人版用户命名空间是否存在
 
